<?php
// Set the Content-Type to JSON for proper handling by browsers
header('Content-Type: application/manifest+json');

try {
    // Include necessary initialization files for site configuration
    require_once('assets/init.php');

    // Dynamically fetch site settings with fallbacks for missing values
    $siteName = !empty($wo['config']['siteName']) ? $wo['config']['siteName'] : $_SERVER['HTTP_HOST']; // Use domain if site name is unavailable
    $siteShortName = !empty($wo['config']['siteShortName']) ? $wo['config']['siteShortName'] : substr($siteName, 0, 12); // Default short name
    $siteDescription = !empty($wo['config']['siteDesc']) ? $wo['config']['siteDesc'] : "Welcome to $siteName, your ultimate platform for managing and exploring content.";
    $themeUrl = !empty($wo['config']['theme_url']) ? $wo['config']['theme_url'] : '/theme'; // Theme directory URL
    $siteUrl = !empty($wo['config']['site_url']) ? $wo['config']['site_url'] : '/'; // Base site URL

    // Define the manifest array dynamically
    $manifest = [
        "name" => $siteName, // Full dynamic app name
        "short_name" => $siteShortName, // Short dynamic name
      "description" => trim($siteDescription), // Dynamic app description
        "start_url" => "/", // Entry point of the app
		

		 "id" => "$siteShortNameApp?version=1&mode=trial",
        "scope" => "/", // Limits navigation to the app's domain
        "display" => "minimal-ui", // Standalone mode to mimic a native app
        "orientation" => "portrait", // Locks app to portrait mode
        "background_color" => "#fd7f20", // Background color for splash screen
        "theme_color" => "#fd7f20", // Theme color for browser UI
		"iarc_rating_id" => "ABCD-1234-5678",
		"prefer_related_applications" => false ,
        "lang" => "en-US", // Language code for content
        "dir" => "ltr", // Left-to-right text flow
        "gcm_sender_id" => "482941778795", // Google Cloud Messaging sender ID
        "DO_NOT_CHANGE_GCM_SENDER_ID" => "Do not change the GCM Sender ID", // Informational message
        "categories" => ["social", "utilities", "productivity"], // Categories for app stores
		

        // Edge side panel support
        "edge_side_panel" => [
            "preferred_panel" => "400"
        
		
		],
		 "serviceworker" => [
        "src" => "$siteUrl/service-worker.js",
        "scope" => "/",
        "type" => "classic"
    ],
"launch_handler" => [
        "client_mode" => "navigate"
    ], 
    
"scope_extensions" => [
    [
        "origin" => "$siteUrl/blogs",
        
    ]
],
		 
        // Handle navigation links within the app
        "handle_links" => [
            "scope" => "/",
            "urls" => ["*"]
        ],

        // Share target configuration for sharing content into the app
    "share_target" => [
    "action" => "/sharer",
    "method" => "GET",
   "enctype" => "application/x-www-form-urlencoded",
    "params" => [
        "title" => "title",
            "text" => "description",
            "url" => "url"
        
]]
,

		

        // Icons for PWA at various resolutions
        "icons" => [
            [
                "src" => "$themeUrl/img/pwai/logo-48x48.png", // Smallest icon for tabs and small contexts
                "sizes" => "48x48",
                "type" => "image/png",
                "purpose" => "any"
            ],
            [
                "src" => "$themeUrl/img/pwai/logo-72x72.png", // Medium icon for settings or lists
                "sizes" => "72x72",
                "type" => "image/png",
                "purpose" => "any"
            ],
            [
                "src" => "$themeUrl/img/pwai/logo-96x96.png", // Used in higher-density displays
                "sizes" => "96x96",
                "type" => "image/png",
                "purpose" => "any"
            ],
            [
                "src" => "$themeUrl/img/pwai/logo-128x128.png", // Used in higher-density displays
                "sizes" => "128x128",
                "type" => "image/png",
                "purpose" => "any"
            ],
            [
                "src" => "$themeUrl/img/pwai/logo-144x144.png", // Larger icon for app menus
                "sizes" => "144x144",
                "type" => "image/png",
                "purpose" => "any"
            ],
            [
                "src" => "$themeUrl/img/pwai/logo-192x192.png", // Standard icon for app launchers
                "sizes" => "192x192",
                "type" => "image/png",
                "purpose" => "any"
            ],
            [
                "src" => "$themeUrl/img/pwai/logo-384x384.png", // High-resolution icon for large displays
                "sizes" => "384x384",
                "type" => "image/png",
                "purpose" => "any"
            ],
            [
                "src" => "$themeUrl/img/pwai/logo-512x512.png", // Largest icon for installation or splash screens
                "sizes" => "512x512",
                "type" => "image/png",
                "purpose" => "any"
            ]
        ],
		
		// Adding splash screens to the manifest
        "splash_screens" => [
            [
                "src" => "$themeUrl/img/pwai/features.png",
                "orientation" => "portrait"
            ],
            [
                "src" => "$themeUrl/img/pwai/forums.png",
                "orientation" => "landscape"
            ]
        
    ],

		
"screenshots" => [

            [

                "src" => "$themeUrl/img/pwai/screenshot1.png",

                "sizes" => "1080x1920",

                "type" => "image/png",

                "label" => "The App Icon with Shortcuts"

            ],

            [

                "src" => "$themeUrl/img/pwai/screenshot2.png",

                "sizes" => "1080x1920",

                "type" => "image/png",

                "label" => "Splash Screen"

            ],

            [

                "src" => "$themeUrl/img/pwai/screenshot3.png",

                "sizes" => "1080x1920",

                "type" => "image/png",

                "label" => "HomePage"

            ],
	
  [

                "src" => "$themeUrl/img/pwai/features.png",

                "sizes" => "1080x1920",

                "type" => "image/png",

                "label" => "Features"

            ],
          [

                "src" => "$themeUrl/img/pwai/groupss.png",

                "sizes" => "1080x1920",

                "type" => "image/png",

                "label" => "HomePage"

            ],
	
	  [

                "src" => "$themeUrl/img/pwai/forums.png",
                "sizes" => "1080x1920",
                "type" => "image/png",
                "label" => "Forums"

            ],
	
               ["src" => "$themeUrl/img/pwai/explore.png",
                "sizes" => "1080x1920",
                "type" => "image/png",
                "label" => "HomePage"],
        

 
    [
        "src" => "$themeUrl/img/pwai/desktoplogin.png",
        "sizes" => "2400x1600",
        "type" => "image/png",
        "form_factor" => "wide",
        "label" => "Desktop Login"
    ],
    [
        "src" => "$themeUrl/img/pwai/desktoplogout.png",
        "sizes" => "2400x1600",
        "type" => "image/png",
        "form_factor" => "wide",
        "label" => "Desktop Logout"
    ]
],


		
        // Shortcuts for quick access to app features
        "shortcuts" => [
            [
                "name" => "Blogs",
                "short_name" => "Blogs",
                "description" => "Access the latest blogs on $siteName",
                "url" => "/blogs",
                "icons" => [
                    [
                        "src" => "$themeUrl/img/pwai/blog.png",
                        "sizes" => "64x64",
                        "type" => "image/png"
                    ]
                ]
            ],
            [
                "name" => "Forum",
                "short_name" => "Forum",
                "description" => "Join discussions in the forum on $siteName",
                "url" => "/forum",
                "icons" => [
                    [
                        "src" => "$themeUrl/img/pwai/forum.png",
                        "sizes" => "64x64",
                        "type" => "image/png"
                    ]]
                
            ],
            [
                "name" => "Reels",
                "short_name" => "Reels",
                "description" => "Watch trending reels on $siteName",
                "url" => "/reels",
                "icons" => [
                    [
                        "src" => "$themeUrl/img/pwai/reels.png",
                        "sizes" => "64x64",
                        "type" => "image/png"
                    ]
                ]
            ],
            [
                "name" => "Events",
                "short_name" => "Events",
                "description" => "Explore upcoming events on $siteName",
                "url" => "/events",
                "icons" => [
                    [
                        "src" => "$themeUrl/img/pwai/events.png",
                        "sizes" => "64x64",
                        "type" => "image/png"
                    ]
                ]
            ],
            [
                "name" => "Advertise",
                "short_name" => "Ads",
                "description" => "Create and manage advertisements on $siteName",
                "url" => "/advertise",
                "icons" => [
                    [
                        "src" => "$themeUrl/img/pwai/ads.png",
                        "sizes" => "64x64",
                        "type" => "image/png"
                    ]
                ]
            ],
            [
                "name" => "Products",
                "short_name" => "Products",
                "description" => "View and manage products on $siteName",
                "url" => "/products",
                "icons" => [
                    [
                        "src" => "$themeUrl/img/pwai/market.png",
                        "sizes" => "64x64",
                        "type" => "image/png"
                    ]
                ]
            ]
        ]
    ];


    // Encode the manifest as JSON and output
    echo json_encode($manifest, JSON_PRETTY_PRINT | JSON_UNESCAPED_SLASHES);

} catch (Exception $e) {
    // Log error details and output a generic error message
    error_log($e->getMessage());
    http_response_code(500);
    echo json_encode(["error" => "Manifest generation failed."]);
}
?>
